@if defined echo (echo %echo% ) else echo off
setlocal

@REM master script of update installer launcher
@REM Copyright IBM Corp. 2000-2001
@REM THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
@REM All Rights Reserved * Licensed Materials - Property of IBM
@REM US Government Users Restricted Rights - Use, duplication or disclosure
@REM restricted by GSA ADP Schedule Contract with IBM Corp.

@REM set DEBUG=yes to turn on debugging statements
set DEBUG_UPDATE=no

:Launch
set LaunchTitle=%0
Echo Starting [ %LaunchTitle% ] and writing install logs to %LaunchTitle%.log
set LOGFILENAME="%LaunchTitle%.log"

:CheckEnvironmentVariable
Echo.
IF "%DEBUG_UPDATE%" == "yes" Echo Checking Environment Variable
echo CheckEnvironmentVariable > %LOGFILENAME% 2>&1
echo IF "%TC_ROOT%" == "" GOTO MissingEnvVariable >> %LOGFILENAME% 2>&1
IF "%TC_ROOT%" == "" GOTO MissingEnvVariable
echo IF "%WAS_HOME%" == "" GOTO MissingEnvVariable >> %LOGFILENAME% 2>&1
IF "%WAS_HOME%" == "" GOTO MissingEnvVariable

:VerifyUser
Echo.
Echo Verifying User >> %LOGFILENAME% 2>&1
IF "%DEBUG_UPDATE%" == "yes" Echo Verifying User
%TC_ROOT%\bin\bash --login -c "id | grep Administrator" >> %LOGFILENAME% 2>&1
IF %ERRORLEVEL% == 1 GOTO IncorrectUser

:MigrationDetect
Echo 
Echo Detect if this is a 1.1.2 to 2.1.0 migration >> %LOGFILENAME% 2>&1
IF NOT EXIST %TIO_HOME%\properties\version\THINKCONTROL.product GOTO IFRepair 
GOTO MigrationRepair

:MigrationRepair
Echo This is a 1.1.2 to 2.1.0 migrated system >> %LOGFILENAME% 
Echo must delete the old THINKCONTROL.product >> %LOGFILENAME% 
mv -f %TIO_HOME%\properties\version\THINKCONTROL.product %TIO_HOME%\properties\version\THINKCONTROL.product.bak >> %LOGFILENAME% 2>&1
IF %ERRORLEVEL% == 1 GOTO NotEnoughAuthority

Echo chmod to newtree directories in order to move files in lib and to write fixpack files >> %LOGFILENAME% 
%TC_ROOT%\bin\bash --login -c "for DIR in .tools COP apps bin config drivers export images lib logs nls sql tmp tools xml; do chmod -R a+rw $TIO_HOME/$DIR; done;" >> %LOGFILENAME% 2>&1
IF %ERRORLEVEL% == 1 GOTO NotEnoughAuthority

Echo moving old jars in %TIO_HOME%\lib to %TIO_HOME%\_backup\lib >> %LOGFILENAME% 
%TC_ROOT%\bin\bash --login -c "if [ ! -d $TIO_HOME/_backup/lib ]; then mkdir -p $TIO_HOME/_backup/lib; fi;"
IF %ERRORLEVEL% == 1 GOTO NotEnoughAuthority

%TC_ROOT%\bin\bash --login -c "CURRENT_PATH=`cygpath '%~dp0'`; $CURRENT_PATH/utils/migration_repair.sh"
IF %ERRORLEVEL% == 1 GOTO NotEnoughAuthority
GOTO IFRepair

:IFRepair
Echo check if the system is patched with interim fix one >> %LOGFILENAME%
%TC_ROOT%\bin\bash --login -c "CURRENT_PATH=`cygpath '%~dp0'`; $CURRENT_PATH/IF_repair.sh"
IF %ERRORLEVEL% == 1 GOTO FIXIF
GOTO Wizard

:Wizard
Echo.
Echo Verifying wizard installer.jar exists >> %LOGFILENAME% 2>&1
IF "%DEBUG_UPDATE%" == "yes" Echo Verifying wizard installer.jar exists
IF NOT EXIST "%~dp0installer.jar" GOTO FailWizard
GOTO ParseArgs

:ParseArgs
set PREREQ_DISABLE_INST=
set PREREQ_DISABLE_UNINST=
set FOR_EFIX=
set RUN_JAVA_HOME=C:\WebSphere\AppServer5\java
GOTO ValidateArgs

:ValidateArgs
IF "%2"=="-dpInstall" GOTO SetPrereqInstall
IF "%2"=="-dpUninstall" GOTO SetPrereqUninstall
IF "%2"=="-efixOnly" GOTO SetEFixOnly
IF "%2"=="-skipJDKCopy" GOTO SetExternalJDK

IF "%2"=="" GOTO SetupJDK

IF NOT "%2"=="-usage" Echo Usage error: [ "%2" is an unrecognized argument ]

Echo.
Echo Usage: updateWizard ([install | uninstall ][ -efixOnly | -dpInstall | -dpUninstall | -skipJDKCopy | -usage ])
Echo.
Echo   efixOnly    - Run the installer in EFix Processing mode only. 
Echo   dpInstall   - Disable install prerequisite error locking.	
Echo   dpUninstall - Disable uninstall prerequisite error locking.
Echo   skipJDKCopy - Run the installer directly from JAVA_HOME.
Echo   usage       - Display syntax help. 
Echo.
GOTO Usage

:SetEFixOnly
set FOR_EFIX=-W UpdateActionSelect.disablePTFOptions=yes
shift
GOTO ValidateArgs

:SetPrereqInstall
set PREREQ_DISABLE_INST=-W EfixInstallPrereqError.prereqOverride="yes"
shift
GOTO ValidateArgs  

:SetPrereqUninstall
set PREREQ_DISABLE_UNINST=-W EfixUninstallPrereqError.prereqOverride="yes"
shift
GOTO ValidateArgs

:SetExternalJDK
set RUN_JAVA_HOME=yes
shift
GOTO ValidateArgs

:SetupJDK
set JAVA_TMP=%~dp0java_tmp
IF NOT EXIST "%JAVA_TMP%\bin" GOTO PrepareJDK
IF NOT EXIST "%JAVA_TMP%\bin\java.exe" GOTO PrepareJDK
GOTO UseLocalJDK

:PrepareJDK
IF NOT "%OS%" == "Windows_NT" GOTO Win9xQuoteStrip
GOTO WinNTQuoteStrip

:Win9XQuoteStrip
@REM FOR %%A IN (%JAVA_HOME%) DO SET NEW_JAVA_HOME=%%A
@REM set JAVA_HOME=%NEW_JAVA_HOME%
@REM IF "%JAVA_HOME%" == "" GOTO CheckSetup
IF "%JAVA_HOME%" == "" GOTO CheckSetup
IF "%RUN_JAVA_HOME%" == "yes" GOTO RunOffJavaHome

:WinNTQuoteStrip
set JAVA_HOME_TMP=%JAVA_HOME%
set MOD_JAVA_HOME=%JAVA_HOME_TMP:"=%
set NEW_JAVA_HOME=%MOD_JAVA_HOME:"=%
set JAVA_HOME=%NEW_JAVA_HOME%
IF "%JAVA_HOME%" == "=" GOTO CheckSetup
IF "%RUN_JAVA_HOME%" == "yes" GOTO RunOffJavaHome
GOTO UseJavaHome

:UseLocalJDK
set JAVA_HOME=%JAVA_TMP%
IF "%DEBUG_UPDATE%" == "yes" Echo Using the local copy of the JDK, made previously, for processing:
IF "%DEBUG_UPDATE%" == "yes" Echo JAVA_HOME: [ %JAVA_HOME% ]
IF "%DEBUG_UPDATE%" == "yes" Echo.
GOTO LaunchInstaller

:RunOffJavaHome
Echo No local copy of the JDK will be created.  
Echo The installer will run directly from JAVA_HOME.
Echo.
GOTO LaunchInstaller

:UseJavaHome
IF "%DEBUG_UPDATE%" == "yes" Echo JAVA_HOME was set.
IF "%DEBUG_UPDATE%" == "yes" Echo JAVA_HOME: [ %JAVA_HOME% ]
IF "%DEBUG_UPDATE%" == "yes" Echo.
GOTO TestJDK

:CheckSetup
IF "%DEBUG_UPDATE%" == "yes" Echo JAVA_HOME is not set.
IF "%DEBUG_UPDATE%" == "yes" Echo Attempting to locate setupCmdLine.bat.
IF "%DEBUG_UPDATE%" == "yes" Echo.
IF NOT EXIST "%~dp0..\bin" GOTO FailSetup
IF NOT EXIST "%~dp0..\bin\setupCmdLine.bat" GOTO FailSetup
GOTO CallSetup

:FailSetup
Echo JAVA_HOME must be set before launching the update wizard:
Echo JAVA_HOME was not set;
Echo Set JAVA_HOME manually with the install_root/bin/setupCmdLine.bat or setupClient.bat script.
Echo.
Echo (setupCmdLine.bat or setupClient.bat is usually located beneath your
Echo WebSphere Application Server installation, in the 'bin'
Echo directory.)
Echo.
Echo Exiting.
Echo.
GOTO Usage

:CallSetup
call "%~dp0..\bin\setupCmdLine.bat"
GOTO TestJDK

:TestJDK
IF NOT EXIST "%JAVA_HOME%\bin" GOTO FailJavaHome
IF NOT EXIST "%JAVA_HOME%\bin\java.exe" GOTO FailJavaHome
IF "%RUN_JAVA_HOME%" == "yes" GOTO RunOffJavaHome
GOTO CopyJDK

:FailJavaHome
Echo The JDK was not found within the set JAVA_HOME:
Echo JAVA_HOME: [ %JAVA_HOME%\bin\java.exe ]
Echo.
Echo Exiting.
Echo.
GOTO Usage

:CopyJDK
IF NOT "%FOR_EFIX%"=="" GOTO SkipCopyJDK
IF "%DEBUG_UPDATE%" == "yes" Echo Making local copy of the JDK, which is required
IF "%DEBUG_UPDATE%" == "yes" Echo for PTF processing:
IF "%DEBUG_UPDATE%" == "yes" Echo JAVA_HOME: [ %JAVA_HOME% ]
IF "%DEBUG_UPDATE%" == "yes" Echo JAVA_TMP:  [ %JAVA_TMP% ]
IF "%DEBUG_UPDATE%" == "yes" Echo.
IF NOT EXIST "%JAVA_TMP%" MKDIR "%JAVA_TMP%"
IF NOT EXIST "%JAVA_TMP%" GOTO FailedCopyJDK
XCOPY "%JAVA_HOME%" "%JAVA_TMP%" /E /Q
IF NOT EXIST "%JAVA_TMP%\bin" GOTO FailedCopyJDK
IF NOT EXIST "%JAVA_TMP%\bin\java.exe" GOTO FailedCopyJDK
GOTO OkCopyJDK

:SkipCopyJDK
Echo EFix processing was selected; no local copy of the
Echo JDK will be created.  PTF processing is disabled.
Echo.
GOTO LaunchInstaller

:FailedCopyJDK
Echo The JDK could not be copied into the current directory.
Echo JAVA_HOME: [ %JAVA_HOME% ]
Echo JAVA_TMP:  [ %JAVA_TMP% ]
Echo.
Echo Exiting.
Echo.
GOTO Usage

:OKCopyJDK
IF "%DEBUG_UPDATE%" == "yes" Echo The JDK was successfully copied.
IF "%DEBUG_UPDATE%" == "yes" Echo.
Set JAVA_HOME=%JAVA_TMP%
GOTO LaunchInstaller

:LaunchInstaller
Echo.
Echo Launching the update installer wizard.
Echo Performing dependency check and writing additional information to logs
set WindowsLAF=com.sun.java.swing.plaf.windows.WindowsLookAndFeel
set PATH=%PATH%;"%JAVA_HOME%"\bin
java.exe -DprodHelper=com.ibm.commerce.install.update.WCProductDetectHelper -Dcom.ibm.websphere.update.debug=false -Dcom.ibm.websphere.update.ptf.debug=false -Dswing.defaultlaf=%WindowsLAF% -Xmx256m -cp "%~dp0lib\wcsdepcheck.jar;%~dp0lib\WCextensions.jar;%~dp0installer.jar;%~dp0lib\extfile.jar;%~dp0lib\jtopen.jar" run

GOTO done

:MissingEnvVariable
echo Undefined environment variable, Please ensure that WAS_HOME and TC_ROOT is set
echo Undefined environment variable, Please ensure that WAS_HOME and TC_ROOT is set >> %LOGFILENAME% 2>&1
GOTO done

:IncorrectUser
echo "Incorrect userid, must be Administrator to apply the fix pack"
echo "Incorrect userid, must be Administrator to apply the fixpack" >> %LOGFILENAME% 2>&1
GOTO done

:NotEnoughAuthority
Echo No enough authority to perform migration repair.
Echo need to remove %TIO_HOME%\properties\version\THINKCONTROL.product, move files modified before May 28, 2004 in %TIO_HOME%\lib to %TIO_HOME%\_backup\lib
Echo need to remove %TIO_HOME%\properties\version\THINKCONTROL.product, move files modified before May 28, 2004 in %TIO_HOME%\lib to %TIO_HOME%\_backup\lib >> %LOGFILENAME% 2>&1
Echo then run updateWizard again
mv  -f %TIO_HOME%\properties\version\THINKCONTROL.product %TIO_HOME%\properties\version\THINKCONTROL.product.bak >> %LOGFILENAME% 2>&1
GOTO done

:FIXIF
Echo need to change the level in %TIO_HOME%\properties\version\TIO.product to 1057, version to 2.1.0.0 before applying fixpack
Echo need to remove the contents in %TIO_HOME%\properties\version\history before applying fixpack
Echo need to change the level in %TIO_HOME%\properties\version\TIO.product to 1057, version to 2.1.0.0 before applying fixpack >> %LOGFILENAME% 2>&1
Echo need to remove the contents in %TIO_HOME%\properties\version\history before applying fixpack >> %LOGFILENAME% 2>&1
GOTO done


:FailWizard
Echo The wizard jar file does not exist, exiting
Echo.
GOTO usage

:Usage
echo "Usage: updateWizard"
endlocal

:done
Echo Exiting, Please check %LaunchTitle%.log for more information
Echo.
Echo 
Echo 
Echo.
Echo End of [ %LaunchTitle% ] script
Echo.
endlocal
